@@ -35,8 +35,8 @@ class ftpUtil:
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
-            prj = "P" + prj_id.zfill(6)
-            remotepath = self.__remotedir_stud + prj
+            pid="P" + prj_id.zfill(6)
+            remotepath = self.__remotedir_stud + pid
             try:
                 sftp.chdir(remotepath)
             except:
@@ -44,7 +44,7 @@ class ftpUtil:
                 sftp.chdir(remotepath)
             stud = stud_id.zfill(11)
             no = no_file.zfill(8)
-            remote_file = prj + "_" + stud + "_" + no + ftype
+            remote_file = pid + "_" + stud + "_" + no + ftype
             sftp.put(local_path, remote_file)
             print('上传成功......')
             sftp.close()
@@ -58,7 +58,7 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
-            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,fdesc,fsize,duration,ftype)
+            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,fdesc,fsize,duration,ftype,pid)
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
