@@ -67,13 +67,13 @@ class mysqlUtil:
         return None
 
     # 添加上传文件记录
-    def sftp_file_ins(self, filename, url, stud, fdesc, fsize, duration, ftype):
+    def sftp_file_ins(self, filename, url, stud, fdesc, fsize, duration, ftype,pid):
         try:
-            df = pd.DataFrame(columns=['filename', 'url', 'stud', 'fdesc', 'fsize', 'duration', 'ftype'])
+            df = pd.DataFrame(columns=['filename', 'url', 'stud', 'fdesc', 'fsize', 'duration', 'ftype','pid'])
             # print(df)
             row1 = pd.DataFrame(
                 {'filename': filename, 'url': url, 'stud': stud, 'fdesc': fdesc, 'fsize': fsize, 'duration': duration,
-                 'ftype': ftype}, index=[1])
+                 'ftype': ftype,'pid':pid}, index=[1])
             # print(row1)
             # df=df.append(row1,ignore_index=True)
             df = pd.concat([df, row1], ignore_index=True)  # append过时，改用concat
@@ -101,6 +101,25 @@ class mysqlUtil:
             return results
         else:
             return None
+        # 获了上传文件记录
+
+    def get_files_bypid(self, pid):
+        if pid:
+            pid = str(pid).upper()
+            sql = 'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where pid="{}" order by uptime desc limit 100'.format(
+                pid)
+        else:
+            pid = "P023101"
+            'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where pid="{}" order by uptime desc limit 100'.format(
+                pid)
+        df = pd.read_sql(sql, self.engine)
+        results = json.loads(df.to_json(orient='records'))
+        if results and len(results) == 1:
+            return results[0]
+        elif results and len(results) > 1:
+            return results
+        else:
+            return None
 
     def process_item(self, item, tblname):
         data = pd.DataFrame(dict(item), index=[0])
